@@ -428,7 +428,12 @@ make_datatable_for_cro = function(cell_var,
                                   subgroup){
     
     max_nrow = max(NROW(cell_var), NROW(col_var), NROW(row_var), NROW(weight))
-    non_empty_rows = valid(cell_var) & valid(col_var) & if_null(subgroup, TRUE)
+    if(is.null(subgroup)){
+        non_empty_rows = valid(cell_var) & valid(col_var) 
+    } else {
+        non_empty_rows = valid(cell_var) & valid(col_var)  & subgroup & !is.na(subgroup)
+    }
+    
     col_var = recycle_if_single_row(col_var, max_nrow)
     cell_var = recycle_if_single_row(cell_var, max_nrow)
     
@@ -1013,7 +1018,17 @@ make_total_rows = function(need_row_var,
         dtotal
     })
     if(length(total_statistic)>1){
+        # restore factor levels
+        old_levels = lapply(total_row[[1]], levels)
         total_row = rbindlist(total_row, fill = FALSE, use.names = TRUE)
+        
+        # workaround for new behavior of data.table - rbind drop levels so we restore them
+        for(i in seq_along(total_row)){
+            if(!is.null(old_levels[[i]])){
+                levels(total_row[[i]]) = old_levels[[i]]
+            }
+        }
+        
     } else {
         total_row = total_row[[1]]
     }
