@@ -126,9 +126,6 @@ data.table::chorder
 #' @export
 data.table::CJ
 
-#' @export
-data.table::dcast
-
 #' @export
 data.table::fintersect
 
@@ -174,9 +171,6 @@ data.table::key
 #' @export
 data.table::like
 
-#' @export
-data.table::melt
-
 #' @export
 data.table::rbindlist
 
