@@ -5,14 +5,18 @@
 #' muliple-response set with category encoding and result of \code{mdset} is 
 #' considered as multiple response set with dichotomy (dummy) encoding e. g. 
 #' with 0 or 1 in the each column. Each column in the \code{dichotomy} is 
-#' indicator of absense or presense of particular feature. Both functions don't 
+#' indicator of absence or presence of particular feature. Both functions don't 
 #' convert its arguments to anything - it is supposed that arguments already 
 #' have appropriate encoding. For conversation see \link{as.dichotomy} or 
-#' \link{as.category}. \code{mrset_p} and \code{mdset_p} select variables for
-#' multiple-responses by perl-style regular expresssion.
-#' \code{mrset_f} and \code{mdset_f} select variables by fixed pattern. Fixed
-#' pattern can be unquoted. For details see \link{..p}.
-#'
+#' \link{as.category}. 
+#' \itemize{
+#' \item{\code{mrset_f} and \code{mdset_f} }{select variables by fixed pattern. Fixed
+#' pattern can be unquoted. For details see \link{..f}.}
+#' \item{\code{mrset_p} and \code{mdset_p} }{select variables for
+#' multiple-responses by perl-style regular expresssion. For details see \link{..p}.}
+#' \item{\code{mrset_t} and \code{mdset_t} }{select variables by expanding text
+#' arguments. For details see \link{..t} and \link{text_expand}.}
+#' }
 #' @param ... variables
 #' @param label character optional label for multiple response set
 #'
@@ -30,6 +34,9 @@
 #' 
 #' # same result
 #' calc_cro_cpct(product_test, mrset_p("a1_"))
+#' 
+#' # same result
+#' calc_cro_cpct(product_test, mrset_t("a1_{1:6}"))
 mrset = function(..., label = NULL){
     args = list(...)
     stopif(!length(args), "`mrset` - you should provide at least one argument.")
@@ -95,4 +102,18 @@ mrset_p = function(..., label = NULL){
 mdset_p = function(..., label = NULL){
     res = eval.parent(substitute(..p(...)))
     do.call(mdset, c(list(res), list(label = label)))    
+}
+
+#' @export
+#' @rdname mrset
+mrset_t = function(..., label = NULL){
+    res = eval.parent(substitute(..t(...)))
+    do.call(mrset, c(list(res), list(label = label)))    
+}
+
+#' @export
+#' @rdname mrset
+mdset_t = function(..., label = NULL){
+    res = eval.parent(substitute(..t(...)))
+    do.call(mdset, c(list(res), list(label = label)))    
 }
\ No newline at end of file
